@@ -17,13 +17,11 @@
 ###########################################################
 # standard libraries
 from datetime import datetime as dt
-import gc
 
 # external packages
 import PyQt5
 import numpy as np
 from matplotlib import ticker
-import matplotlib.pyplot as plt
 
 # local import
 from gui.utilities import toolsQtWidget
@@ -59,8 +57,8 @@ class MeasureWindow(toolsQtWidget.MWidget):
         self.plotFunc = {'No chart': None,
                          'RA Stability': self.plotRa,
                          'DEC Stability': self.plotDec,
-                         'RA Angular Stability': self.plotAngularPosRa,
-                         'DEC Angular Stability': self.plotAngularPosDec,
+                         'RA Angular Error': self.plotErrorAngularPosRa,
+                         'DEC Angular Error': self.plotErrorAngularPosDec,
                          'Temperature': self.plotTemperature,
                          'Pressure': self.plotPressure,
                          'Humidity': self.plotHumidity,
@@ -79,8 +77,8 @@ class MeasureWindow(toolsQtWidget.MWidget):
                           '128s Ticks  -  9 hours window': 128,
                           }
 
-        self.measureMat = self.embedMatplot(self.ui.measure, constrainedLayout=False)
-        self.measureMat.parentWidget().setStyleSheet(self.BACK_BG)
+        self.measureMat = self.embedMatplot(self.ui.measure, constrainedLayout=True)
+        self.measureMat.parentWidget().setStyleSheet(self.mw4Style)
 
     def initConfig(self):
         """
@@ -115,8 +113,8 @@ class MeasureWindow(toolsQtWidget.MWidget):
         if 'measureW' not in self.app.config:
             self.app.config['measureW'] = {}
         config = self.app.config['measureW']
-        config['winPosX'] = self.pos().x()
-        config['winPosY'] = self.pos().y()
+        config['winPosX'] = max(self.pos().x(), 0)
+        config['winPosY'] = max(self.pos().y(), 0)
         config['height'] = self.height()
         config['width'] = self.width()
         config['measureSet1'] = self.ui.measureSet1.currentIndex()
@@ -134,6 +132,7 @@ class MeasureWindow(toolsQtWidget.MWidget):
         self.ui.measureSet1.currentIndexChanged.connect(self.setCycleRefresh)
         self.ui.measureSet2.currentIndexChanged.connect(self.setCycleRefresh)
         self.ui.measureSet3.currentIndexChanged.connect(self.setCycleRefresh)
+        self.app.colorChange.connect(self.colorChange)
         self.app.update1s.connect(self.cycleRefresh)
         return True
 
@@ -148,9 +147,18 @@ class MeasureWindow(toolsQtWidget.MWidget):
         self.ui.measureSet1.currentIndexChanged.disconnect(self.setCycleRefresh)
         self.ui.measureSet2.currentIndexChanged.disconnect(self.setCycleRefresh)
         self.ui.measureSet3.currentIndexChanged.disconnect(self.setCycleRefresh)
-        plt.close(self.measureMat.figure)
+        self.app.colorChange.disconnect(self.colorChange)
         super().closeEvent(closeEvent)
 
+    def colorChange(self):
+        """
+        :return:
+        """
+        self.setStyleSheet(self.mw4Style)
+        self.measureMat.parentWidget().setStyleSheet(self.mw4Style)
+        self.drawMeasure()
+        return True
+
     def setupButtons(self):
         """
         setupButtons prepares the dynamic content od the buttons in measurement
@@ -187,6 +195,7 @@ class MeasureWindow(toolsQtWidget.MWidget):
         """
         :return: True for test purpose
         """
+        self.setStyleSheet(self.mw4Style)
         cycle = self.timeScale.get(self.ui.timeSet.currentText(), 1)
         if not self.refreshCounter % cycle:
             self.drawMeasure(cycle=cycle)
@@ -207,18 +216,15 @@ class MeasureWindow(toolsQtWidget.MWidget):
         if numberPlots < 0:
             return None
 
-        for axe in figure.axes:
-            axe.cla()
-            gc.collect()
-
         figure.clf()
         figure.subplots_adjust(left=0.1, right=0.95, bottom=0.05, top=0.95)
 
         for i in range(numberPlots):
-            self.measureMat.figure.add_subplot(numberPlots, 1, i + 1, facecolor=None)
+            self.measureMat.figure.add_subplot(numberPlots, 1, i + 1,
+                                               facecolor=self.M_BACK)
 
         for axe in figure.axes:
-            axe.set_facecolor((0, 0, 0, 0))
+            axe.set_facecolor(self.M_BACK)
             axe.tick_params(colors=self.M_BLUE,
                             labelsize=12)
             axe.spines['bottom'].set_color(self.M_BLUE)
@@ -298,7 +304,7 @@ class MeasureWindow(toolsQtWidget.MWidget):
                                                                       ))
         return True
 
-    def plotAngularPosRa(self, axe=None, title='', data=None, cycle=None):
+    def plotErrorAngularPosRa(self, axe=None, title='', data=None, cycle=None):
         """
         :param axe: axe for plotting
         :param title: title text
@@ -306,7 +312,7 @@ class MeasureWindow(toolsQtWidget.MWidget):
         :param cycle: cycle time for measurement
         :return: success
         """
-        ylabel = 'Delta RA Angular [arcsec]'
+        ylabel = 'Error RA Angular [arcsec]'
         start = -self.NUMBER_POINTS * cycle
         axe.set_title(title,
                       color=self.M_BLUE,
@@ -317,13 +323,13 @@ class MeasureWindow(toolsQtWidget.MWidget):
                        fontweight='bold',
                        fontsize=12)
         axe.plot(data['time'][start:-1:cycle],
-                 data['deltaAngularPosRA'][start:-1:cycle],
+                 data['errorAngularPosRA'][start:-1:cycle],
                  marker=None,
                  markersize=3,
                  color=self.M_WHITE,
                  )
         axe.grid(True, color=self.M_GREY, alpha=1)
-        axe.set_ylim(-4, 4)
+        axe.set_ylim(-40, 40)
         axe.get_yaxis().set_major_locator(ticker.MaxNLocator(nbins=8,
                                                              integer=True,
                                                              min_n_ticks=4,
@@ -333,7 +339,7 @@ class MeasureWindow(toolsQtWidget.MWidget):
                                                                       ))
         return True
 
-    def plotAngularPosDec(self, axe=None, title='', data=None, cycle=None):
+    def plotErrorAngularPosDec(self, axe=None, title='', data=None, cycle=None):
         """
         :param axe: axe for plotting
         :param title: title text
@@ -341,7 +347,7 @@ class MeasureWindow(toolsQtWidget.MWidget):
         :param cycle: cycle time for measurement
         :return: success
         """
-        ylabel = 'Delta DEC Angular [arcsec]'
+        ylabel = 'Error DEC Angular [arcsec]'
         start = -self.NUMBER_POINTS * cycle
         axe.set_title(title,
                       color=self.M_BLUE,
@@ -352,13 +358,13 @@ class MeasureWindow(toolsQtWidget.MWidget):
                        fontweight='bold',
                        fontsize=12)
         axe.plot(data['time'][start:-1:cycle],
-                 data['deltaAngularPosDEC'][start:-1:cycle],
+                 data['errorAngularPosDEC'][start:-1:cycle],
                  marker=None,
                  markersize=3,
                  color=self.M_WHITE,
                  )
         axe.grid(True, color=self.M_GREY, alpha=1)
-        axe.set_ylim(-4, 4)
+        axe.set_ylim(-40, 40)
         axe.get_yaxis().set_major_locator(ticker.MaxNLocator(nbins=8,
                                                              integer=True,
                                                              min_n_ticks=4,
@@ -452,14 +458,14 @@ class MeasureWindow(toolsQtWidget.MWidget):
                            data['powTemp'][start:-1:cycle],
                            marker=None,
                            markersize=3,
-                           color=self.M_PINK,
+                           color=self.M_PINK1,
                            )
             r8, = axe.plot(data['time'][start:-1:cycle],
                            data['powDew'][start:-1:cycle],
                            marker=None,
                            markersize=3,
                            linestyle=':',
-                           color=self.M_PINK,
+                           color=self.M_PINK1,
                            )
             plotList.append(r7)
             plotList.append(r8)
@@ -629,7 +635,7 @@ class MeasureWindow(toolsQtWidget.MWidget):
                            data['powHum'][start:-1:cycle],
                            marker=None,
                            markersize=3,
-                           color=self.M_PINK,
+                           color=self.M_PINK1,
                            )
             plotList.append(r4)
             labelList.append('Power Hum')
@@ -796,7 +802,7 @@ class MeasureWindow(toolsQtWidget.MWidget):
                            data['powCurr1'][start:-1:cycle],
                            marker=None,
                            markersize=3,
-                           color=self.M_PINK,
+                           color=self.M_PINK1,
                            )
             r3, = axe.plot(data['time'][start:-1:cycle],
                            data['powCurr2'][start:-1:cycle],
