@@ -18,12 +18,13 @@
 # standard libraries
 
 # external packages
+from PyQt5.QtGui import QImage, QPixmap
 import PyQt5.QtCore
 import PyQt5.QtGui
 import PyQt5.QtWidgets
 import requests
 import numpy as np
-import qimage2ndarray
+from qimage2ndarray import rgb_view, array2qimage
 
 # local import
 from base.tpool import Worker
@@ -46,22 +47,17 @@ class Environ(object):
         # environment functions
         signals = self.app.sensorWeather.signals
         signals.deviceDisconnected.connect(self.clearSensorWeatherGui)
-
         # skymeter functions
         signals = self.app.skymeter.signals
         signals.deviceDisconnected.connect(self.clearSkymeterGui)
-
         # power weather functions
         signals = self.app.powerWeather.signals
         signals.deviceDisconnected.connect(self.clearPowerWeatherGui)
-
         # weather functions
         self.app.onlineWeather.signals.dataReceived.connect(self.updateOnlineWeatherGui)
-
         # weather functions
         self.app.mount.signals.settingDone.connect(self.updateDirectWeatherGui)
         self.app.mount.signals.settingDone.connect(self.updateRefractionUpdateType)
-
         # gui connections
         self.ui.setRefractionManual.clicked.connect(self.updateRefractionParameters)
         self.ui.isOnline.stateChanged.connect(self.updateClearOutside)
@@ -71,7 +67,6 @@ class Environ(object):
         self.ui.checkRefracNone.clicked.connect(self.setRefractionUpdateType)
         self.ui.checkRefracCont.clicked.connect(self.setRefractionUpdateType)
         self.ui.checkRefracNoTrack.clicked.connect(self.setRefractionUpdateType)
-
         # cyclic functions
         self.app.update1s.connect(self.updateFilterRefractionParameters)
         self.app.update1s.connect(self.updateRefractionParameters)
@@ -88,7 +83,6 @@ class Environ(object):
         self.ui.checkRefracNone.setChecked(config.get('checkRefracNone', False))
         self.ui.checkRefracCont.setChecked(config.get('checkRefracCont', False))
         self.ui.checkRefracNoTrack.setChecked(config.get('checkRefracNoTrack', False))
-
         self.refractionSource = config.get('refractionSource', '')
         self.setRefractionSourceGui()
         return True
@@ -194,15 +188,14 @@ class Environ(object):
         if self.refractionSource == 'onlineWeather':
             if not self.app.onlineWeather.data:
                 return False
+
             temp = self.app.onlineWeather.data['temperature']
             press = self.app.onlineWeather.data['pressure']
-
         elif self.refractionSource == 'sensorWeather':
             key = 'WEATHER_PARAMETERS.WEATHER_TEMPERATURE'
             temp = self.app.sensorWeather.data.get(key, None)
             key = 'WEATHER_PARAMETERS.WEATHER_PRESSURE'
             press = self.app.sensorWeather.data.get(key, None)
-
         else:
             temp = None
             press = None
@@ -214,14 +207,12 @@ class Environ(object):
 
         if self.filteredTemperature is None:
             self.filteredTemperature = np.full(100, temp)
-
         else:
             self.filteredTemperature = np.roll(self.filteredTemperature, 1)
             self.filteredTemperature[0] = temp
 
         if self.filteredPressure is None:
             self.filteredPressure = np.full(100, press)
-
         else:
             self.filteredPressure = np.roll(self.filteredPressure, 1)
             self.filteredPressure[0] = press
@@ -355,11 +346,9 @@ class Environ(object):
 
         :return: success for test
         """
-
         self.ui.powerTemp.setText('-')
         self.ui.powerHumidity.setText('-')
         self.ui.powerDewPoint.setText('-')
-
         return True
 
     def updatePowerWeatherGui(self):
@@ -369,7 +358,6 @@ class Environ(object):
 
         :return: success for test
         """
-
         value = self.app.powerWeather.data.get('WEATHER_PARAMETERS.WEATHER_TEMPERATURE', 0)
         self.guiSetText(self.ui.powerTemp, '4.1f', value)
 
@@ -378,7 +366,6 @@ class Environ(object):
 
         value = self.app.powerWeather.data.get('WEATHER_PARAMETERS.WEATHER_DEWPOINT', 0)
         self.guiSetText(self.ui.powerDewPoint, '4.1f', value)
-
         return True
 
     def getWebDataWorker(self, url=''):
@@ -391,20 +378,18 @@ class Environ(object):
 
         try:
             data = requests.get(url, timeout=30)
-
         except Exception as e:
-            self.log.critical(f'{url} general exception: {e}')
+            self.log.critical(f'URL: [{url}] general exception: [{e}]')
             return None
 
         if data.status_code != 200:
-            self.log.warning(f'{url}: status nok')
+            self.log.warning(f'URL: [{url}] status nok')
             return None
 
-        self.log.trace(f'{url}: {data.status_code}')
+        self.log.trace(f'URL: [{url}] status: [{data.status_code}]')
         return data
 
-    @staticmethod
-    def processClearOutsideImage(image=None):
+    def processClearOutsideImage(self, image=None):
         """
         processClearOutsideImage takes the image, split it and puts the image
         to the Gui. for the transformation qimage2ndarray is used because of
@@ -414,28 +399,25 @@ class Environ(object):
         :param image:
         :return: success
         """
-        dim = 0.85
-        image.convertToFormat(PyQt5.QtGui.QImage.Format_RGB32)
-        imageBase = image.copy(0, 84, 624, 141)
+        back = self.hex2rgb(self.M_BACK)
+        m = np.mean(back)
+        dim = max((m / 256), 0.66)
+
+        image.convertToFormat(QImage.Format_RGB32)
+        imageBase = image.copy(94, 84, 585, 141)
 
         # transformation are done in numpy, because it's much faster
         width = imageBase.width()
         height = imageBase.height()
-        imgArr = qimage2ndarray.rgb_view(imageBase)
+        imgArr = rgb_view(imageBase)
         imgArr = imgArr.reshape(width * height, 3)
-        img_Max = np.maximum(255 - imgArr, [32, 32, 32])
-        temp = imgArr[:, 0] == imgArr[:, 1]
-        check = np.array([temp, temp, temp]).transpose()
-
-        # do the transform light to dark theme
-        imgArr = np.where(check, img_Max, imgArr)
 
         # transforming back
         imgArr = imgArr.reshape(height, width, 3)
 
         # Compressing the image as the widget content is a png
         # removing some rows
-        m = np.isin(imgArr, [[32, 32, 32], [255, 0, 0]])
+        m = np.isin(imgArr, [[255, 0, 0]])
         toDelete = []
         maxRow = 1
         line = maxRow
@@ -449,9 +431,8 @@ class Environ(object):
         imgArr = np.delete(imgArr, toDelete, axis=0)
 
         # re transfer to QImage from numpy array
-        imageBase = qimage2ndarray.array2qimage(dim * imgArr)
-        pixmapBase = PyQt5.QtGui.QPixmap().fromImage(imageBase)
-
+        imageBase = array2qimage(dim * imgArr)
+        pixmapBase = QPixmap().fromImage(imageBase)
         return pixmapBase
 
     def updateClearOutsideImage(self, data=None):
