@@ -36,9 +36,8 @@ from logic.modeldata.modelHandling import writeRetrofitData
 class Model:
     """
     """
-
     # define a max error which throws point out of queue in arcsec (this is
-    # 10 degrees
+    # 10 degrees)
     MAX_ERROR_MODEL_POINT = 10 * 60 * 60
 
     def __init__(self):
@@ -50,6 +49,7 @@ class Model:
         self.retryQueue = queue.Queue()
         self.collector = QMultiWait()
         self.startModeling = None
+        self.performanceTimingSignal = None
         self.modelName = ''
         self.model = []
         self.imageDir = ''
@@ -74,6 +74,10 @@ class Model:
         self.ui.retriesReverse.setChecked(config.get('retriesReverse', False))
         self.ui.parkMountAfterModel.setChecked(config.get('parkMountAfterModel', False))
         self.ui.numberBuildRetries.setValue(config.get('numberBuildRetries', 0))
+        self.ui.progressiveTiming.setChecked(config.get('progressiveTiming', False))
+        self.ui.normalTiming.setChecked(config.get('normalTiming', True))
+        self.ui.conservativeTiming.setChecked(config.get('conservativeTiming', False))
+
         return True
 
     def storeConfig(self):
@@ -84,6 +88,9 @@ class Model:
         config['retriesReverse'] = self.ui.retriesReverse.isChecked()
         config['parkMountAfterModel'] = self.ui.parkMountAfterModel.isChecked()
         config['numberBuildRetries'] = self.ui.numberBuildRetries.value()
+        config['progressiveTiming'] = self.ui.progressiveTiming.isChecked()
+        config['normalTiming'] = self.ui.normalTiming.isChecked()
+        config['conservativeTiming'] = self.ui.conservativeTiming.isChecked()
         return True
 
     def updateAlignGUI(self, model):
@@ -309,9 +316,8 @@ class Model:
         """
         noImagesLeft = self.imageQueue.empty()
         slewsLeft = not self.slewQueue.empty()
-        stillToWork = slewsLeft
 
-        if noImagesLeft and stillToWork:
+        if noImagesLeft and slewsLeft:
             t = f'Slews left: [{self.slewQueue.qsize()}] '
             self.log.error(f'Empty image queue: {t}')
             return False
@@ -481,6 +487,7 @@ class Model:
         :return: true for test purpose
         """
         self.collector.addWaitableSignal(self.app.mount.signals.slewFinished)
+        self.collector.addWaitableSignal(self.app.camera.signals.exposeReady)
 
         hasDome = self.deviceStat.get('dome', False)
         hasAzimuth = 'ABS_DOME_POSITION.DOME_ABSOLUTE_POSITION' in self.app.dome.data
@@ -490,10 +497,22 @@ class Model:
         elif hasDome and not hasAzimuth:
             self.app.message.emit('Dome without azimuth value used', 2)
 
+        t = f'Modeling config dome:[{hasDome}], hasAzimuth:[{hasAzimuth}]'
+        self.log.debug(t)
+
         self.collector.ready.connect(self.modelImage)
-        self.app.camera.signals.integrated.connect(self.modelSlew)
         self.app.camera.signals.saved.connect(self.modelSolve)
         self.app.astrometry.signals.done.connect(self.modelSolveDone)
+        self.app.camera.signals.exposeReady.emit()
+
+        if self.ui.progressiveTiming.isChecked():
+            self.performanceTimingSignal = self.app.camera.signals.integrated
+        elif self.ui.normalTiming.isChecked():
+            self.performanceTimingSignal = self.app.camera.signals.downloaded
+        else:
+            self.performanceTimingSignal = self.app.camera.signals.saved
+
+        self.performanceTimingSignal.connect(self.modelSlew)
         return True
 
     def restoreSignalsModelDefault(self):
@@ -503,8 +522,8 @@ class Model:
 
         :return: true for test purpose
         """
+        self.performanceTimingSignal.disconnect(self.modelSlew)
         self.app.camera.signals.saved.disconnect(self.modelSolve)
-        self.app.camera.signals.integrated.disconnect(self.modelSlew)
         self.app.astrometry.signals.done.disconnect(self.modelSolveDone)
         self.collector.ready.disconnect(self.modelImage)
         self.collector.clear()
