@@ -216,10 +216,6 @@ class SettDevice:
 
     def initConfig(self):
         """
-        initConfig read the key out of the configuration dict. if some drivers configuration
-        are missing, the default values are loaded from the drivers. after that we have a
-        fully cleaned config dict and we can proceed initializing the gui and the drivers
-
         :return: True for test purpose
         """
         config = self.app.config['mainW']
@@ -241,10 +237,6 @@ class SettDevice:
 
     def storeConfig(self):
         """
-        storeConfig writes the keys to the configuration dict and stores. if some
-        saving has to be proceeded to persistent data, they will be launched as
-        well in this method.
-
         :return: True for test purpose
         """
         config = self.app.config['mainW']
@@ -285,12 +277,12 @@ class SettDevice:
 
     def processPopupResults(self):
         """
-        processPopupResults takes sets the actual drop down in the device settings lists to
-        the choice of the popup window. after that it starts the driver again.
+        processPopupResults takes sets the actual drop down in the device settings
+        lists to the choice of the popup window. after that it starts the driver
+        again.
 
         :return: success if new device could be selected
         """
-
         self.popupUi.ui.ok.clicked.disconnect(self.processPopupResults)
         driver = self.popupUi.returnValues.get('driver')
 
@@ -319,9 +311,10 @@ class SettDevice:
 
     def copyConfig(self, driver='', framework=''):
         """
-        copyConfig transfers all information of the actual driver to all other drivers of
-        the same framework. if done so, all other drivers running on the same framework have
-        to be stopped, copied parameters, initialized and started, too.
+        copyConfig transfers all information of the actual driver to all other
+        drivers of the same framework. if done so, all other drivers running on
+        the same framework have to be stopped, copied parameters, initialized and
+        started, too.
 
         :param driver:
         :param framework:
@@ -355,10 +348,10 @@ class SettDevice:
 
     def callPopup(self, driver):
         """
-        callPopup prepares the data and calls and processes the returned data for the given
-        driver.
-        if copy flags for some frameworks are given, the properties of the actual driver
-        will be copied to all other drivers with the same framework.
+        callPopup prepares the data and calls and processes the returned data for
+        the given driver.
+        if copy flags for some frameworks are given, the properties of the actual
+        driver will be copied to all other drivers with the same framework.
 
         :param driver:
         :return: True for test purpose
@@ -408,7 +401,7 @@ class SettDevice:
             driverClass.run[framework].deviceName = ''
             self.app.message.emit(f'Disabled device:     [{driver}]', 0)
 
-        self.drivers[driver]['uiDropDown'].setStyleSheet(self.BACK_NORM)
+        self.drivers[driver]['uiDropDown'].setStyleSheet(f'background-color: {self.M_BACK};')
         self.deviceStat[driver] = None
 
         return True
@@ -447,9 +440,9 @@ class SettDevice:
         but for internal driver this has to be done separately.
 
         as the configuration is stored in the config, start also stores the selected
-        framework in the framework attribute of the driver's class. this is needed as when
-        stopping the driver the config dict already has the new framework set and we have to
-        remember it.
+        framework in the framework attribute of the driver's class. this is needed as
+        when stopping the driver the config dict already has the new framework set
+        and we have to remember it.
 
         :param driver:
         :param autoStart:
@@ -468,7 +461,7 @@ class SettDevice:
         driverClass.framework = framework
         isInternal = framework == 'internal'
         if isInternal:
-            self.drivers[driver]['uiDropDown'].setStyleSheet(self.BACK_GREEN)
+            self.drivers[driver]['uiDropDown'].setStyleSheet(f'background-color: {self.M_GREEN};')
 
         self.configDriver(driver=driver)
         if autoStart:
@@ -493,7 +486,7 @@ class SettDevice:
             if invalid:
                 continue
 
-            isAscom = self.driversData[driver]['framework'] == 'ascom'
+            isAscom = self.driversData[driver]['framework'] in ['ascom', 'alpaca']
             if isAscom and not isAscomAutoConnect:
                 autoStart = False
             else:
@@ -510,7 +503,7 @@ class SettDevice:
             if driver not in self.driversData:
                 continue
 
-            isAscom = self.driversData[driver]['framework'] == 'ascom'
+            isAscom = self.driversData[driver]['framework'] in ['ascom', 'alpaca']
             if isAscom:
                 self.stopDriver(driver=driver)
         return True
@@ -523,7 +516,7 @@ class SettDevice:
             if driver not in self.driversData:
                 continue
 
-            isAscom = self.driversData[driver]['framework'] == 'ascom'
+            isAscom = self.driversData[driver]['framework'] in ['ascom', 'alpaca']
             if isAscom:
                 self.startDriver(driver=driver, autoStart=True)
         return True
@@ -594,8 +587,8 @@ class SettDevice:
             if not self.scanValid(driver=driver, deviceName=deviceName):
                 continue
 
-            self.drivers[driver]['uiDropDown'].setStyleSheet(self.BACK_NORM)
-            # self.app.message.emit(f'Disconnected server: [{driver}] ', 0)
+            self.drivers[driver]['uiDropDown'].setStyleSheet(f'background-color: {self.M_BACK};')
+            self.app.message.emit(f'Disconnected server: [{driver}] ', 0)
         return True
 
     def deviceConnected(self, deviceName):
@@ -610,9 +603,9 @@ class SettDevice:
             if not self.scanValid(driver=driver, deviceName=deviceName):
                 continue
 
-            self.drivers[driver]['uiDropDown'].setStyleSheet(self.BACK_GREEN)
+            self.drivers[driver]['uiDropDown'].setStyleSheet(f'background-color: {self.M_GREEN};')
             self.deviceStat[driver] = True
-            # self.app.message.emit(f'{driver} connected', 0)
+            self.app.message.emit(f'Device connected:    [{driver}]', 0)
         return True
 
     def deviceDisconnected(self, deviceName):
@@ -624,7 +617,7 @@ class SettDevice:
             if not self.scanValid(driver=driver, deviceName=deviceName):
                 continue
 
-            self.drivers[driver]['uiDropDown'].setStyleSheet(self.BACK_NORM)
+            self.drivers[driver]['uiDropDown'].setStyleSheet(f'background-color: {self.M_BACK};')
             self.deviceStat[driver] = False
-            # self.app.message.emit(f'{driver} disconnected', 0)
+            self.app.message.emit(f'Disconnected device: [{driver}]', 0)
         return True
