@@ -144,13 +144,13 @@ class AutomateWindows(QObject):
         key = winreg.OpenKey(HKEY_LOCAL_MACHINE, regPath)
         subkey = winreg.OpenKey(key, nameKey)
         values = self.convertRegistryEntryToDict(subkey)
+        self.log.debug(f'Registry key:[{nameKey}], values:[{values}]')
         winreg.CloseKey(subkey)
         winreg.CloseKey(key)
 
         return values
 
-    @staticmethod
-    def searchNameInRegistry(appName, key):
+    def searchNameInRegistry(self, appName, key):
         """
         :param appName:
         :param key:
@@ -158,6 +158,7 @@ class AutomateWindows(QObject):
         """
         for i in range(0, winreg.QueryInfoKey(key)[0]):
             nameKey = winreg.EnumKey(key, i)
+            self.log.debug(f'Registry app:[{key}], values:[{nameKey}]')
             if appName in nameKey:
                 break
         else:
@@ -213,6 +214,7 @@ class AutomateWindows(QObject):
         """
         for appName in appNames:
             avail, path, name = self.extractPropertiesFromRegistry(appName)
+            self.log.debug(f'Registry avail:[{avail}], path:[{path}], name:[{name}]')
             if avail:
                 exe = appNames[appName]
                 break
@@ -273,12 +275,14 @@ class AutomateWindows(QObject):
 
         try:
             self.updater.start(self.installPath + self.updaterEXE)
-        except AppStartError:
-            self.log.error('Failed to start updater, please check!')
+        except AppStartError as e:
+            e = e.replace('\n', '')
+            self.log.error(f'Start error: [{e}]')
             self.log.error(f'Path: [{self.installPath}{self.updaterEXE}]')
             return False
         except Exception as e:
-            self.log.error(f'Failed to start updater, error [{e}]')
+            e = e.replace('\n', '')
+            self.log.error(f'General error: [{e}]')
             self.log.error(f'Path: [{self.installPath}{self.updaterEXE}]')
             return False
         else:
@@ -315,7 +319,7 @@ class AutomateWindows(QObject):
         :return:
         """
         if not self.installPath:
-            self.log.error(f'No updater found: {self.installPath}')
+            self.log.error(f'No updater available: {self.installPath}')
             return False
 
         self.updater = None
