@@ -20,47 +20,26 @@ import logging
 import platform
 
 # external packages
-import PyQt5
-from PyQt5.QtTest import QTest
 
 # local imports
+from base.driverDataClass import Signals
 from logic.camera.cameraIndi import CameraIndi
 from logic.camera.cameraAlpaca import CameraAlpaca
 if platform.system() == 'Windows':
     from logic.camera.cameraAscom import CameraAscom
 
 
-class CameraSignals(PyQt5.QtCore.QObject):
-    """
-    """
-
-    __all__ = ['CameraSignals']
-
-    integrated = PyQt5.QtCore.pyqtSignal()
-    saved = PyQt5.QtCore.pyqtSignal(object)
-    message = PyQt5.QtCore.pyqtSignal(object)
-
-    serverConnected = PyQt5.QtCore.pyqtSignal()
-    serverDisconnected = PyQt5.QtCore.pyqtSignal(object)
-    deviceConnected = PyQt5.QtCore.pyqtSignal(str)
-    deviceDisconnected = PyQt5.QtCore.pyqtSignal(str)
-
-
 class Camera:
+    """
+    """
 
-    __all__ = ['Camera',
-               ]
-
+    __all__ = ['Camera']
     log = logging.getLogger(__name__)
 
     def __init__(self, app):
-
         self.app = app
         self.threadPool = app.threadPool
-        self.signals = CameraSignals()
-        # todo: to be removed
-        self.exposing = False
-
+        self.signals = Signals()
         self.data = {}
         self.defaultConfig = {'framework': '',
                               'frameworks': {}}
@@ -72,31 +51,10 @@ class Camera:
 
         if platform.system() == 'Windows':
             self.run['ascom'] = CameraAscom(self.app, self.signals, self.data)
-            ascomSignals = self.run['ascom'].ascomSignals
-            ascomSignals.serverConnected.connect(self.signals.serverConnected)
-            ascomSignals.serverDisconnected.connect(self.signals.serverDisconnected)
-            ascomSignals.deviceConnected.connect(self.signals.deviceConnected)
-            ascomSignals.deviceDisconnected.connect(self.signals.deviceDisconnected)
 
         for fw in self.run:
             self.defaultConfig['frameworks'].update(self.run[fw].defaultConfig)
 
-        # signalling from subclasses to main
-        alpacaSignals = self.run['alpaca'].client.signals
-        alpacaSignals.serverConnected.connect(self.signals.serverConnected)
-        alpacaSignals.serverDisconnected.connect(self.signals.serverDisconnected)
-        alpacaSignals.deviceConnected.connect(self.signals.deviceConnected)
-        alpacaSignals.deviceDisconnected.connect(self.signals.deviceDisconnected)
-
-        indiSignals = self.run['indi'].client.signals
-        indiSignals.serverConnected.connect(self.signals.serverConnected)
-        indiSignals.serverDisconnected.connect(self.signals.serverDisconnected)
-        indiSignals.deviceConnected.connect(self.signals.deviceConnected)
-        indiSignals.deviceDisconnected.connect(self.signals.deviceDisconnected)
-
-        # todo: to be removed
-        self.signals.saved.connect(self.resetExposed)
-
     def startCommunication(self, loadConfig=False):
         """
         :param loadConfig:
@@ -184,14 +142,6 @@ class Camera:
         else:
             return False
 
-    # todo: to be removed
-    def resetExposed(self):
-        """
-        :return: True for test purpose
-        """
-        self.exposing = False
-        return True
-
     def expose(self,
                imagePath='',
                expTime=3,
@@ -223,14 +173,6 @@ class Camera:
 
         posX, posY, width, height = result
 
-        # todo: to be removed with new signal combination
-        # this protects against overrun
-        if self.exposing:
-            self.log.warning('Expose overrun happened')
-        while self.exposing:
-            QTest.qWait(250)
-        self.exposing = True
-
         text = f'Image bin:{binning}, posX:{posX}, posY:{posY}'
         text += f', width:{width}, height:{height}, fast:{fastReadout}'
         self.log.debug(text)
@@ -249,8 +191,6 @@ class Camera:
         """
         :return: success
         """
-        # todo: to be removed
-        self.exposing = False
         if self.framework not in self.run.keys():
             return False
 
