@@ -30,20 +30,14 @@ from base.transform import JNowToJ2000
 
 class CameraIndi(IndiClass):
     """
-        >>> c = CameraIndi(app=None, signals=None, data=None)
     """
 
-    __all__ = ['CameraIndi',
-               ]
-
-    # update rate to 1000 milli seconds for setting indi server
-    UPDATE_RATE = 1000
+    __all__ = ['CameraIndi']
 
     def __init__(self, app=None, signals=None, data=None):
-        super().__init__(app=app, data=data, threadPool=app.threadPool)
-
-        self.threadPool = app.threadPool
         self.signals = signals
+        super().__init__(app=app, data=data, threadPool=app.threadPool)
+        self.threadPool = app.threadPool
         self.data = data
         self.imagePath = ''
         self.ra = None
@@ -99,79 +93,37 @@ class CameraIndi(IndiClass):
 
     def setExposureState(self):
         """
-        setExposureState rebuilds the state information integrated and download as it
-        is not explicit defined in the INDI spec. So downloaded is reached when that        
-        INDI state for CCD_EXPOSURE goes to IDLE or OK -> Jasem Mutlaq. Another definition
-        is done by myself, when INDI state for CCD_EXPOSURE is BUSY and the CCD_EPOSURE_VALUE
-        is not 0, then we should be on integration side, else the download shoulds be started.
-        The whole stuff is made, because on ALPACA and ASCOM side it's a step by step 
-        sequence, which has very defined states for each step and I would like ta have a 
-        common approach for all frameworks. 
-  
+        setExposureState rebuilds the state information integrated and download
+        as it is not explicit defined in the INDI spec. So downloaded is reached
+        when that INDI state for CCD_EXPOSURE goes to IDLE or OK -> Jasem  Mutlaq.
+        Another definition is done by myself, when INDI state for CCD_EXPOSURE is
+        BUSY and the CCD_EPOSURE_VALUE is not 0, then we should be on integration
+        side, else the download shoulds be started. The whole stuff is made,
+        because on ALPACA and ASCOM side it's a step by step sequence, which has
+        very defined states for each step and I would like ta have a common
+        approach for all frameworks.
+
         :return: success
         """
-        # todo: if setExp only called, when prop is CCD_EXP, then there 
-        # todo: should be no check against it. 
-        
-        if not hasattr(self.device, 'CCD_EXPOSURE'):
-            return False
-
-        # todo: does it makes sense not to set a default for the value,
-        # todo: but to check if the entry is already there if ..is None
-        
-        # if busy is set one packet before EXP_Value is set, then we send
-        # slew before we have integrated the image, just because we set the value
-        # to 0 if no entry is made.
-        
-        # What about setting busy, but keeping the old value of exposure in?
-        # This value will be in any case 0 after the last exposure. Does ist make
-        # sense to remove this value from the dict if we check for None in the future
-        
-        # Question to be answered: if a INDI driver reports back zero exposure, is he
-        # really in download mode ?
-        
-        value = self.data.get('CCD_EXPOSURE.CCD_EXPOSURE_VALUE', 0)
-        if self.device.CCD_EXPOSURE['state'] == 'Idle':
-            self.signals.message.emit('')
-
-        elif self.device.CCD_EXPOSURE['state'] == 'Busy':
-            if value == 0:
-                if not self.isDownloading:
-                    self.signals.integrated.emit()
-                self.isDownloading = True
-                self.signals.message.emit('download')
-
-            else:
-                self.signals.message.emit(f'expose {value:2.0f} s')
-
-        elif self.device.CCD_EXPOSURE['state'] == 'Ok':
-            pass
-            # why having here removed the message emit
-            # self.signals.message.emit('')
-
-        if self.device.CCD_EXPOSURE['state'] in ['Idle', 'Ok']:
-            self.isDownloading = False
-            
-        """
-        as result the following solution would be there:
-        
+        THRESHOLD = 0.00001
         value = self.data.get('CCD_EXPOSURE.CCD_EXPOSURE_VALUE')
         if self.device.CCD_EXPOSURE['state'] == 'Busy':
             if value is None:
                 return False
-            elif value == 0:
+            elif value <= THRESHOLD:
                 if not self.isDownloading:
                     self.signals.integrated.emit()
                 self.isDownloading = True
                 self.signals.message.emit('download')
             else:
                 self.signals.message.emit(f'expose {value:2.0f} s')
-
         elif self.device.CCD_EXPOSURE['state'] in ['Idle', 'Ok']:
-            del(self.data['CCD_EXPOSURE.CCD_EXPOSURE_VALUE'])
+            self.signals.downloaded.emit()
             self.signals.message.emit('')
             self.isDownloading = False
-        """
+        else:
+            t = f'[{self.deviceName}] state: [{self.device.CCD_EXPOSURE["state"]}]'
+            self.log.warning(t)
 
         return True
 
@@ -205,6 +157,15 @@ class CameraIndi(IndiClass):
         header['DEC'] = self.dec.degrees
         return header
 
+    def workerSaveBlobSignalsFinished(self):
+        """
+        :return:
+        """
+        self.signals.saved.emit(self.imagePath)
+        self.signals.exposeReady.emit()
+        self.signals.message.emit('')
+        return True
+
     def workerSaveBLOB(self, data):
         """
         :param data:
@@ -224,16 +185,11 @@ class CameraIndi(IndiClass):
 
         else:
             self.log.info('Image BLOB is not supported')
-            self.signals.saved.emit(self.imagePath)
-            self.signals.message.emit('')
             return True
 
         HDU[0].header = self.updateHeaderInfo(HDU[0].header)
         fits.writeto(self.imagePath, HDU[0].data, HDU[0].header,
                      overwrite=True, output_verify='silentfix+warn')
-
-        self.signals.saved.emit(self.imagePath)
-        self.signals.message.emit('')
         return True
 
     def updateBLOB(self, deviceName, propertyName):
@@ -261,6 +217,7 @@ class CameraIndi(IndiClass):
 
         self.signals.message.emit('Saving')
         worker = Worker(self.workerSaveBLOB, data)
+        worker.signals.finished.connect(self.workerSaveBlobSignalsFinished)
         self.threadPool.start(worker)
         return True
 
@@ -272,7 +229,7 @@ class CameraIndi(IndiClass):
             return False
 
         quality = self.device.getSwitch('READOUT_QUALITY')
-        self.log.debug(f'camera has readout quality entry: {quality}')
+        self.log.debug(f'Camera has readout quality entry: {quality}')
 
         if fastReadout:
             quality['QUALITY_LOW'] = 'On'
