@@ -21,35 +21,20 @@
 
 # local imports
 from base.alpacaClass import AlpacaClass
-from base.alpacaBase import ObservingConditions
 
 
 class SensorWeatherAlpaca(AlpacaClass):
     """
-    the class Dome inherits all information and handling of the Dome device. there will be
-    some parameters who will define the slewing position of the dome relating to the
-    mount.dome = DomeAlpaca(app=None)
     """
 
-    __all__ = ['SensorWeatherAlpaca',
-               ]
+    __all__ = ['SensorWeatherAlpaca']
 
     def __init__(self, app=None, signals=None, data=None):
         super().__init__(app=app, data=data, threadPool=app.threadPool)
 
-        # as we have in the base class only the base client there, we will get more
-        # specialized with Dome (which is derived from the base class)
-        self.client = ObservingConditions()
         self.signals = signals
         self.data = data
 
-    def getInitialConfig(self):
-        """
-        :return: true for test purpose
-        """
-        super().getInitialConfig()
-        return True
-
     def workerPollData(self):
         """
         :return: true for test purpose
@@ -57,8 +42,12 @@ class SensorWeatherAlpaca(AlpacaClass):
         if not self.deviceConnected:
             return False
 
-        self.data['WEATHER_PARAMETERS.WEATHER_TEMPERATURE'] = self.client.temperature()
-        self.data['WEATHER_PARAMETERS.WEATHER_PRESSURE'] = self.client.pressure()
-        self.data['WEATHER_PARAMETERS.WEATHER_DEWPOINT'] = self.client.dewpoint()
-        self.data['WEATHER_PARAMETERS.WEATHER_HUMIDITY'] = self.client.humidity()
+        self.getAndStoreAlpacaProperty('temperature',
+                                       'WEATHER_PARAMETERS.WEATHER_TEMPERATURE')
+        self.getAndStoreAlpacaProperty('pressure',
+                                       'WEATHER_PARAMETERS.WEATHER_PRESSURE')
+        self.getAndStoreAlpacaProperty('dewpoint',
+                                       'WEATHER_PARAMETERS.WEATHER_DEWPOINT')
+        self.getAndStoreAlpacaProperty('humidity',
+                                       'WEATHER_PARAMETERS.WEATHER_HUMIDITY')
         return True
